api.users.v1.test_helpers.user package — Argus-Toolbelt 1.0 documentation

# api.users.v1.test_helpers.user package

## Submodules

## api.users.v1.test_helpers.user.check_permission module

`api.users.v1.test_helpers.user.check_permission.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user/w+/permission/w+, respond with HTTP 403

`api.users.v1.test_helpers.user.check_permission.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user/w+/permission/w+, respond with HTTP 404

`api.users.v1.test_helpers.user.check_permission.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user/w+/permission/w+, respond with HTTP 200

`api.users.v1.test_helpers.user.check_permission.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user/w+/permission/w+, respond with HTTP 401

## api.users.v1.test_helpers.user.find_users module

`api.users.v1.test_helpers.user.find_users.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user/search, respond with HTTP 403

`api.users.v1.test_helpers.user.find_users.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user/search, respond with HTTP 404

`api.users.v1.test_helpers.user.find_users.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user/search, respond with HTTP 200

`api.users.v1.test_helpers.user.find_users.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user/search, respond with HTTP 401

## api.users.v1.test_helpers.user.get_functions module

`api.users.v1.test_helpers.user.get_functions.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user/w+/functions, respond with HTTP 403

`api.users.v1.test_helpers.user.get_functions.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user/w+/functions, respond with HTTP 404

`api.users.v1.test_helpers.user.get_functions.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user/w+/functions, respond with HTTP 200

`api.users.v1.test_helpers.user.get_functions.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user/w+/functions, respond with HTTP 401

## api.users.v1.test_helpers.user.get_profile module

`api.users.v1.test_helpers.user.get_profile.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user/w+, respond with HTTP 403

`api.users.v1.test_helpers.user.get_profile.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user/w+, respond with HTTP 404

`api.users.v1.test_helpers.user.get_profile.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user/w+, respond with HTTP 200

`api.users.v1.test_helpers.user.get_profile.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user/w+, respond with HTTP 401

## api.users.v1.test_helpers.user.get_user_by_username module

`api.users.v1.test_helpers.user.get_user_by_username.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user/w+, respond with HTTP 403

`api.users.v1.test_helpers.user.get_user_by_username.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user/w+, respond with HTTP 404

`api.users.v1.test_helpers.user.get_user_by_username.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user/w+, respond with HTTP 200

`api.users.v1.test_helpers.user.get_user_by_username.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user/w+, respond with HTTP 401

## api.users.v1.test_helpers.user.get_user_customers module

`api.users.v1.test_helpers.user.get_user_customers.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user/w+/customers, respond with HTTP 403

`api.users.v1.test_helpers.user.get_user_customers.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user/w+/customers, respond with HTTP 404

`api.users.v1.test_helpers.user.get_user_customers.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user/w+/customers, respond with HTTP 200

`api.users.v1.test_helpers.user.get_user_customers.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user/w+/customers, respond with HTTP 401

## api.users.v1.test_helpers.user.list_users module

`api.users.v1.test_helpers.user.list_users.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user, respond with HTTP 403

`api.users.v1.test_helpers.user.list_users.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user, respond with HTTP 404

`api.users.v1.test_helpers.user.list_users.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user, respond with HTTP 200

`api.users.v1.test_helpers.user.list_users.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user, respond with HTTP 401

## api.users.v1.test_helpers.user.update_profile_picture_for_user module

`api.users.v1.test_helpers.user.update_profile_picture_for_user.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user/w+/picture, respond with HTTP 403

`api.users.v1.test_helpers.user.update_profile_picture_for_user.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user/w+/picture, respond with HTTP 404

`api.users.v1.test_helpers.user.update_profile_picture_for_user.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user/w+/picture, respond with HTTP 200

`api.users.v1.test_helpers.user.update_profile_picture_for_user.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/user/w+/picture, respond with HTTP 401

## Module contents